| Title: | Interactive visualization for Illumina methylation arrays |
|---|---|
| Description: | Interactive tool for visualizing Illumina methylation array data. Both the 450k and EPIC array are supported. |
| Authors: | Jean-Philippe Fortin [cre, aut], Kasper Daniel Hansen [aut] |
| Maintainer: | Jean-Philippe Fortin <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.49.0 |
| Built: | 2026-06-02 11:07:05 UTC |
| Source: | https://github.com/bioc/shinyMethyl |
Function to run the interactive shinyMethyl session from a shinyMethylSet object.
runShinyMethyl(shinyMethylSet1, shinyMethylSet2 = NULL)runShinyMethyl(shinyMethylSet1, shinyMethylSet2 = NULL)
shinyMethylSet1 |
|
shinyMethylSet2 |
Optional |
No value returned. Instead the shinyMethyl interactive session is launched.
Jean-Philippe Fortin
if (interactive()){ library(minfi) library(minfiData) baseDir <- system.file("extdata", package = "minfiData") targets <- read.metharray.sheet(baseDir) targets$Sample_Plate <- substr(targets$Slide,1,7) RGSet <- read.metharray.exp(targets=targets) summarized.data <- shinySummarize(RGSet) runShinyMethyl(summarized.data) }if (interactive()){ library(minfi) library(minfiData) baseDir <- system.file("extdata", package = "minfiData") targets <- read.metharray.sheet(baseDir) targets$Sample_Plate <- substr(targets$Slide,1,7) RGSet <- read.metharray.exp(targets=targets) summarized.data <- shinySummarize(RGSet) runShinyMethyl(summarized.data) }
This class holds summarized data from Illumina methylation microarrays for interactive visualization purpose.
## Constructor shinyMethylSet(sampleNames = new("character"), phenotype = new("data.frame"), mQuantiles = new(vector("list",5)), betaQuantiles = new(vector("list",5)), methQuantiles = new(vector("list",5)), unmethQuantiles = new(vector("list",5)), cnQuantiles = new(vector("list",5)), greenControls = new(vector("list",12)), redControls = new(vector("list",12)), pca = new("list"), originObject = new("character"), array = new("character")) ## Data extraction / Accessors ## S4 method for signature 'shinyMethylSet' getMeth(object) ## S4 method for signature 'shinyMethylSet' getUnmeth(object) ## S4 method for signature 'shinyMethylSet' getBeta(object) ## S4 method for signature 'shinyMethylSet' getM(object) ## S4 method for signature 'shinyMethylSet' getCN(object) ## S4 method for signature 'shinyMethylSet' pData(object) ## S4 method for signature 'shinyMethylSet' sampleNames(object)## Constructor shinyMethylSet(sampleNames = new("character"), phenotype = new("data.frame"), mQuantiles = new(vector("list",5)), betaQuantiles = new(vector("list",5)), methQuantiles = new(vector("list",5)), unmethQuantiles = new(vector("list",5)), cnQuantiles = new(vector("list",5)), greenControls = new(vector("list",12)), redControls = new(vector("list",12)), pca = new("list"), originObject = new("character"), array = new("character")) ## Data extraction / Accessors ## S4 method for signature 'shinyMethylSet' getMeth(object) ## S4 method for signature 'shinyMethylSet' getUnmeth(object) ## S4 method for signature 'shinyMethylSet' getBeta(object) ## S4 method for signature 'shinyMethylSet' getM(object) ## S4 method for signature 'shinyMethylSet' getCN(object) ## S4 method for signature 'shinyMethylSet' pData(object) ## S4 method for signature 'shinyMethylSet' sampleNames(object)
object |
A |
sampleNames |
A character vector |
phenotype |
A |
methQuantiles |
A list of 5 matrices containing several quantiles for the methylation values (between zero and infinity) separated by probe tpye and autosomal/sex probes. Each row is a quantile and each column is a sample. |
unmethQuantiles |
Similar to |
betaQuantiles |
Similar to |
mQuantiles |
Similar to |
cnQuantiles |
Similar to |
greenControls |
A list containing the matrices of different raw control probes intensities in the green channel |
redControls |
Similar to |
pca |
List containing the PCA scores for the 20,000 most variable CpGs and the percentages of variance explained |
originObject |
Name of the minfi object from which the data were extracted |
array |
Name of the Illumina array platform: 450k or EPIC |
These class is a representation of a Meth matrix and a
Unmeth matrix linked to a pData data frame.
A creationMethod slot is present to indicate from which object type
the shinyMethylSet has been created: either a
RGChannelSet or GenomicRatioSet
A MethylSet stores meth and Unmeth.
Instances are constructed using the shinyMethylSet function with the
arguments outlined above.
In the following code, object is a shinyMethylSet.
getMeth(object), getUnmeth(object)
Get the Meth or Unmeth matrix.
getBeta(object)get Beta, see details.
getM(object)get M-values, see details.
getCN(object)get copy number values which are defined as the sum of the methylation and unmethylation channel.
sampleNames(object)Get the sampleNames
combine(object1,object2)combine shinyMethylSet objects
Jean-Philippe Fortin
Objects of this class are typically created by using the function
shinySummarize on a RGChannelSet or
GenomicRatioSet.
showClass("shinyMethylSet")showClass("shinyMethylSet")
Summarizing methylation data from a RGChannelSet or GenomicRatioSet into a shinyMethylSet needed to launch the interactive interface of shinyMethyl. That works for both the 450k and EPIC arrays.
## S4 method for signature 'RGChannelSet' shinySummarize(object) ## S4 method for signature 'GenomicRatioSet' shinySummarize(object)## S4 method for signature 'RGChannelSet' shinySummarize(object) ## S4 method for signature 'GenomicRatioSet' shinySummarize(object)
object |
Either a |
Either a RGChannelSet is transformed into a shinyMethylSet, or a GenomicRatioSet is transformed to a shinyMethylSet
Jean-Philippe Fortin
shinyMethylSet for the output object and
RGChannelSet or GenomicRatioSet for the input object.
if (require(minfiData)){ library(minfiData) summarized.data <- shinySummarize(RGsetEx) }if (require(minfiData)){ library(minfiData) summarized.data <- shinySummarize(RGsetEx) }